@@ -8,18 +8,17 @@
 #  For more information, see the Coopr README.txt file.
 #  _________________________________________________________________________
 
-from sys import stderr as SE
-
+import sys
 import pyutilib.component.core
 
 pyutilib.component.core.PluginGlobals.push_env( 'coopr.opt' )
 
-from base import *
-from results import *
-import solver
-import reader
-from problem import *
-from parallel import *
+from coopr.opt.base import *
+from coopr.opt.results import *
+import coopr.opt.solver
+import coopr.opt.reader
+from coopr.opt.problem import *
+from coopr.opt.parallel import *
 
 pyutilib.component.core.PluginGlobals.pop_env()
 
@@ -33,8 +32,9 @@ try:
     for entrypoint in pkg_resources.iter_entry_points('coopr.opt'):
         try:
             plugin_class = entrypoint.load()
-        except Exception, err:
-            SE.write( "Error loading coopr.opt entry point: %s  entrypoint='%s'\n" % (err, entrypoint) )
-except Exception, err:
-    SE.write( "Error loading coopr.opt entry points\n" )
+        except Exception:
+            msg = sys.exc_info()[1]
+            sys.stderr.write( "Error loading coopr.opt entry point: %s  entrypoint='%s'\n" % (msg, entrypoint) )
+except Exception:
+    sys.stderr.write( "Error loading coopr.opt entry points\n" )
 
