@@ -29,4 +29,4 @@ class AbstractProblemWriter(ManagedPlugin):
         self.format=problem_format
 
     def __call__(self, model, filename, solver_capability, **kwds): #pragma:nocover
-        raise TypeError, "Method __call__ undefined in writer for format "+str(self.format)
+        raise TypeError("Method __call__ undefined in writer for format "+str(self.format))
