@@ -21,9 +21,6 @@ import pyutilib.common
 import pyutilib.misc
 import pyutilib.services
 
-# need to do the below for the is_constructed check - just can't yet due to a circular dependency
-#from coopr.pyomo.base import Block
-
 from coopr.opt.base.convert import convert_problem
 from coopr.opt.base.formats import ResultsFormat, ProblemFormat
 import coopr.opt.base.results
@@ -58,6 +55,7 @@ def _extract_version(x, length=4):
         return version
     return None #(0,0,0,0)[:length]
 
+
 class IOptSolver(Interface):
     """Interface class for creating optimization solvers"""
 
@@ -99,7 +97,9 @@ def __solver_call__(self, _name=None, args=[], **kwds):
         pyutilib.services.register_executable(name=_name)
         if pyutilib.services.registered_executable(_name):
             if mode == 'nl':
-                opt = PluginFactory(IOptSolver._factory_cls['_asl'], args, **kwds)
+                if "asl" not in IOptSolver._factory_cls:
+                    raise RuntimeError("The asl solver plugin was not registered as a valid solver plugin - cannot construct solver plugin with IO mode=nl")
+                opt = PluginFactory(IOptSolver._factory_cls['asl'], args, **kwds)
             elif mode == 'os':
                 opt = PluginFactory(IOptSolver._factory_cls['_ossolver'], args, **kwds)
             if not opt is None:
@@ -110,7 +110,6 @@ def __solver_call__(self, _name=None, args=[], **kwds):
 pyutilib.misc.add_method(SolverFactory, __solver_call__, name='__call__')
 
 
-#class OptSolver(ManagedPlugin):
 class OptSolver(Plugin):
     """A generic optimization solver"""
 
@@ -120,7 +119,6 @@ class OptSolver(Plugin):
         """ Constructor """
 
         Plugin.__init__(self,**kwds)
-
         #
         # The 'type' is the class type of the solver instance
         #
@@ -166,6 +164,11 @@ class OptSolver(Plugin):
         # "my_favorite_variable[1,2,3]", instead of "v1" when requested (useful for debugging).
         self.symbolic_solver_labels = False
 
+        # when communciating with a solver, output bounds for fixed variables. useful in 
+        # cases where it is desireable to minimize the amount of preprocessing performed
+        # in response to variable fixing/freeing.
+        self.output_fixed_variable_bounds = False
+
         self._problem_format=None
         self._results_format=None
         self._valid_problem_formats=[]
@@ -175,6 +178,11 @@ class OptSolver(Plugin):
         self._assert_available=False
         self._report_timing = False # timing statistics are always collected, but optionally reported.
         self.suffixes = [] # a list of the suffixes the user has request be loaded in a solution.
+        #
+        # Data for solver callbacks
+        #
+        self.allow_callbacks = False
+        self._callback = {}
 
         # We define no capabilities for the generic solver; base classes must override this
         self._capabilities = pyutilib.misc.Options()
@@ -256,25 +264,29 @@ class OptSolver(Plugin):
 
     def solve(self, *args, **kwds):
         """ Solve the problem """
-        
         from coopr.pyomo.base import Block
         from coopr.pyomo.base.suffix import Suffix, active_import_suffix_generator
+        #
         # If the inputs are models, then validate that they have been
         # constructed! Collect suffix names to try and import from solution.
         #
+        _model = None
         for arg in args:
             if isinstance(arg, Block) is True:
                 if arg.is_constructed() is False:
                     raise RuntimeError(
                         "Attempting to solve model=%s with unconstructed "
                         "component(s)" % (arg.name,) )
+                _model = arg 
+                #
                 # Collect suffixes, but only if the suffix keyword is not
                 # already defined. The user passing suffix names in this
-                # keyword will override this automitic collection of all
+                # keyword will override this automatic collection of all
                 # active import suffixes. Note if they supply a list
                 # of suffix names but these suffixes are not declared on the
                 # model, it won't matter what gets placed in the results object,
                 # nothing will get loaded into the model.
+                #
                 if not "suffixes" in kwds:
                     kwds['suffixes'] = list(name for (name,comp) in active_import_suffix_generator(arg))
         
@@ -288,6 +300,9 @@ class OptSolver(Plugin):
         self._presolve(*args, **kwds)
         presolve_completion_time = time.time()
         
+        if not _model is None:
+            self._initialize_callbacks(_model)
+
         _status = self._apply_solver()
         if not hasattr(_status, 'rc'):
             logger.warning(
@@ -337,6 +352,8 @@ class OptSolver(Plugin):
                 self._assert_available=True
             elif key == "symbolic_solver_labels":
                 self.symbolic_solver_labels = bool(kwds[key])
+            elif key == "output_fixed_variable_bounds":
+                self.output_fixed_variable_bounds = bool(kwds[key])
             elif key == "suffixes":
                 self.suffixes=kwds[key]
             else:
@@ -359,6 +376,10 @@ class OptSolver(Plugin):
         else:
             self.results_reader = coopr.opt.base.results.ReaderFactory(self._results_format)
 
+    def _initialize_callbacks(self, model):
+        """Initialize call-back functions"""
+        pass
+
     def _apply_solver(self):
         """The routine that performs the solve"""
         raise NotImplementedError       #pragma:nocover
@@ -385,7 +406,8 @@ class OptSolver(Plugin):
                                problem_format, 
                                valid_problem_formats, 
                                self.has_capability,
-                               symbolic_solver_labels=self.symbolic_solver_labels)
+                               symbolic_solver_labels=self.symbolic_solver_labels,
+                               output_fixed_variable_bounds=self.output_fixed_variable_bounds)
 
     def _default_results_format(self, prob_format):
         """Returns the default results format for different problem
@@ -415,3 +437,24 @@ class OptSolver(Plugin):
             except:
                 val = token[(index+1):]
             setattr(self.options, token[:index], val)
+
+    def set_callback(self, name, callback_fn=None):
+        """
+        Set the callback function for a named callback.
+
+        A call-back function has the form:
+
+            def fn(solver, model):
+                pass
+
+        where 'solver' is the native solver interface object and 'model' is 
+        a Pyomo model instance object.
+        """
+        if not self.allow_callbacks:
+            raise pyutilib.common.ApplicationError("Callbacks disabled for solver %s" % self.name)
+        if callback_fn is None:
+            if name in self._callback:
+                del self._callback[name]
+        else:
+            self._callback[name] = callback_fn
+
