@@ -13,10 +13,17 @@ Define the plugin for COLIN XML IO
 """
 
 from pyutilib.component.core import *
-from problem_io import *
+from coopr.opt.blackbox.problem_io import *
 import xml.dom.minidom
 from pyutilib.misc import get_xml_text, tostr
 
+try:
+    unicode
+    intlist = [int, long, float]
+except:
+    basestring = str
+    intlist = [int, float]
+
 
 class ColinXmlIO(SingletonPlugin):
     """The reader/writer for the COLIN XML IO Formats"""
@@ -75,7 +82,7 @@ class ColinXmlIO(SingletonPlugin):
             root.appendChild(elt)
             if isinstance(response[key], basestring):
                 text_elt = doc.createTextNode( response[key] )
-            elif type(response[key]) in [int,long,float]:
+            elif type(response[key]) in intlist:
                 text_elt = doc.createTextNode( str(response[key]) )
             else:
                 text_elt = doc.createTextNode( tostr(response[key]) )
