@@ -16,13 +16,14 @@ can be optimized with the Acro COLIN optimizers.
 __all__ = ['OptProblem', 'RealOptProblem', 'MixedIntOptProblem', 'response_enum']
 
 import os
-from point import MixedIntVars, RealVars
 import re
 import sys
+
 from pyutilib.enum import Enum
-from problem_io import IBlackBoxOptProblemIO
 from pyutilib.component.core import *
 
+from coopr.opt.blackbox.problem_io import IBlackBoxOptProblemIO
+from coopr.opt.blackbox.point import MixedIntVars, RealVars
 
 response_enum = Enum("FunctionValue", "FunctionValues", "Gradient", "Hessian", "NonlinearConstraintValues", "Jacobian")
 
@@ -51,20 +52,20 @@ class OptProblem(object):
         the evaluation.
         """
         if len(argv) < 3:                               #pragma:nocover
-            print argv[0 ]+ " <input> <output> <log>"
+            print(argv[0 ]+ " <input> <output> <log>")
             sys.exit(1)
         #
         # Get enum strings
         #
-        self.response_str = map(str,self.response_types)
+        self.response_str = list(map(str, self.response_types))
         #
         # Parse XML input file
         #
         iomngr = OptProblem.io_manager.service(format)
         if iomngr is None:
-            raise ValueError, "Unknown IO format '%s' for COLIN OptProblem" % str(format)
+            raise ValueError("Unknown IO format '%s' for COLIN OptProblem" % str(format))
         if not os.path.exists(argv[1]):
-            raise IOError, "Unknown input file '%s'" % argv[1]
+            raise IOError("Unknown input file '%s'" % argv[1])
         self._compute_prefix(argv[1])
         point = self.create_point()
         point, requests = iomngr.read(argv[1], point)
@@ -125,7 +126,7 @@ class OptProblem(object):
         Compute the requested results.
         """
         response = {}
-        for key in requests.keys():
+        for key in requests:
             if key not in self.response_str:
                 response[key] = "ERROR: Unsupported application request %s" % str(key)
             #
@@ -173,24 +174,24 @@ class MixedIntOptProblem(OptProblem):
 
     def validate(self, point):
         if len(point.reals) !=  self.nreal:
-            raise ValueError, "Number of reals is "+str(len(point.reals))+" but this problem is configured for "+str(self.nreal)
+            raise ValueError("Number of reals is "+str(len(point.reals))+" but this problem is configured for "+str(self.nreal))
         if len(point.ints) !=  self.nint:
-            raise ValueError, "Number of integers is "+str(len(point.ints))+" but this problem is configured for "+str(self.nint)
+            raise ValueError("Number of integers is "+str(len(point.ints))+" but this problem is configured for "+str(self.nint))
         if len(point.bits) !=  self.nbinary:
-            raise ValueError, "Number of binaries is "+str(len(point.bits))+" but this problem is configured for "+str(self.nbinary)
+            raise ValueError("Number of binaries is "+str(len(point.bits))+" but this problem is configured for "+str(self.nbinary))
         if len(self.int_lower) > 0:
             for i in range(0,self.nint):
                 if self.int_lower[i] is not None and self.int_lower[i] > point.ints[i]:
-                    raise ValueError, "Integer "+str(i)+" has a value "+str(point.ints[i])+" that is lower than the integer lower bound "+str(self.int_lower[i])
+                    raise ValueError("Integer "+str(i)+" has a value "+str(point.ints[i])+" that is lower than the integer lower bound "+str(self.int_lower[i]))
                 if self.int_upper[i] is not None and self.int_upper[i] < point.ints[i]:
-                    raise ValueError, "Integer "+str(i)+" has a value "+str(point.ints[i])+" that is higher than the integer upper bound "+str(self.int_upper[i])
+                    raise ValueError("Integer "+str(i)+" has a value "+str(point.ints[i])+" that is higher than the integer upper bound "+str(self.int_upper[i]))
 
         if len(self.real_lower) > 0:
             for i in range(0,self.nreal):
                 if self.real_lower[i] is not None and self.real_lower[i] > point.reals[i]:
-                    raise ValueError, "Real "+str(i)+" has a value "+str(point.reals[i])+" that is lower than the real lower bound "+str(self.real_lower[i])
+                    raise ValueError("Real "+str(i)+" has a value "+str(point.reals[i])+" that is lower than the real lower bound "+str(self.real_lower[i]))
                 if self.real_upper[i] is not None and self.real_upper[i] < point.reals[i]:
-                    raise ValueError, "Real "+str(i)+" has a value "+str(point.reals[i])+" that is higher than the real upper bound "+str(self.real_upper[i])
+                    raise ValueError("Real "+str(i)+" has a value "+str(point.reals[i])+" that is higher than the real upper bound "+str(self.real_upper[i]))
 
 
 
@@ -210,12 +211,12 @@ class RealOptProblem(OptProblem):
 
     def validate(self, point):
         if len(point.vars) !=  self.nvars:
-            raise ValueError, "Number of real variables is "+str(len(point.vars))+" but this problem is configured for "+str(self.nvars)
+            raise ValueError("Number of real variables is "+str(len(point.vars))+" but this problem is configured for "+str(self.nvars))
         if len(self.lower) > 0:
             for i in range(0,self.nvars):
                 if self.lower[i] is not None and self.lower[i] > point.vars[i]:
-                    raise ValueError, "Variable "+str(i)+" has a value "+str(point.vars[i])+" that is lower than the real lower bound "+str(self.lower[i])
+                    raise ValueError("Variable "+str(i)+" has a value "+str(point.vars[i])+" that is lower than the real lower bound "+str(self.lower[i]))
                 if self.upper[i] is not None and self.upper[i] < point.vars[i]:
-                    raise ValueError, "Variable "+str(i)+" has a value "+str(point.vars[i])+" that is higher than the real upper bound "+str(self.upper[i])
+                    raise ValueError("Variable "+str(i)+" has a value "+str(point.vars[i])+" that is higher than the real upper bound "+str(self.upper[i]))
 
 
