@@ -13,13 +13,16 @@ __all__ = []
 
 from pyutilib.component.core import alias
 
+import coopr.opt
 from coopr.opt.parallel.manager import *
 from coopr.opt.parallel.async_solver import *
 
+import six
+using_py3 = six.PY3
 
 class SolverManager_Serial(AsynchronousSolverManager):
 
-    alias("serial")
+    alias("serial", doc="Synchronously execute solvers locally")
 
     def clear(self):
         """
@@ -39,7 +42,18 @@ class SolverManager_Serial(AsynchronousSolverManager):
             del kwds['opt']
         if self._opt is None:
             raise ActionManagerError("Undefined solver")
-        self.results[ah.id] = self._opt.solve(*args, **kwds)
+
+        if using_py3:
+            if isinstance(self._opt, str):
+                solver = coopr.opt.SolverFactory(self._opt)
+            else:
+                solver = self._opt
+        else:
+            if isinstance(self._opt, basestring):
+                solver = coopr.opt.SolverFactory(self._opt)
+            else:
+                solver = self._opt
+        self.results[ah.id] = solver.solve(*args, **kwds)
         ah.status = ActionStatus.done
         self._ah_list.append(ah)
         return ah
@@ -54,4 +68,4 @@ class SolverManager_Serial(AsynchronousSolverManager):
         """
         if len(self._ah_list) > 0:
             return self._ah_list.pop()
-        return ActionHandle(error=True, explanation="No queued evaluations available in the 'local' solver manager, which only executes solvers synchronously")
+        return ActionHandle(error=True, explanation="No queued evaluations available in the 'serial' solver manager, which executes solvers synchronously")
