@@ -9,8 +9,8 @@
 
 __all__ = ['ProblemInformation', 'ProblemSense']
 
-from container import *
 from pyutilib.enum import Enum
+from coopr.opt.results.container import *
 
 ProblemSense = Enum('unknown', 'minimize', 'maximize')
 
