@@ -8,10 +8,8 @@ import coopr.misc.coopr_parser
 import coopr.opt
 
 def setup_solvers_parser(parser):
-    parser.add_argument("--list", dest="summary", action='store_true', default=False,
-                        help="list the active solvers")
-    parser.add_argument("--options", dest="options", action='store_true', default=False,
-                        help="print the solver options that are supported by solvers")
+    # No options are specified
+    pass
 
 def setup_test_parser(parser):
     parser.add_argument('--csv-file', '--csv', action='store', dest='csv', default=None,
@@ -25,7 +23,29 @@ def setup_test_parser(parser):
 
 def print_solvers():
     wrapper = textwrap.TextWrapper(replace_whitespace=False)
-    print(wrapper.fill("The following pre-defined solver interfaces are recognized by Pyomo:"))
+    print("")
+    print("Coopr Solvers and Solver Managers")
+    print("---------------------------------")
+
+    print(wrapper.fill("Coopr uses 'solver managers' to execute 'solvers' that perform optimization and other forms of model analysis.  A solver directly executes an optimizer, typically using an executable found on the user's PATH environment.  Solver managers support a flexible mechanism for asyncronously executing solvers either locally or remotely.  The following solver managers are available in Coopr:"))
+    print("")
+    solvermgr_list = coopr.opt.SolverManagerFactory.services()
+    solvermgr_list = sorted( filter(lambda x: '_' != x[0], solvermgr_list) )
+    n = max(map(len, solvermgr_list))
+    wrapper = textwrap.TextWrapper(subsequent_indent=' '*(n+9))
+    for s in solvermgr_list:
+        # Disable warnings
+        _level = pyutilib.component.core.PluginGlobals.env().log.getEffectiveLevel()
+        pyutilib.component.core.PluginGlobals.env().log.setLevel(logging.ERROR)
+        format = '    %-'+str(n)+'s     %s'
+        # Reset logging level
+        pyutilib.component.core.PluginGlobals.env().log.setLevel(level=_level)
+        print(wrapper.fill(format % (s , coopr.opt.SolverManagerFactory.doc(s))))
+    print("")
+    wrapper = textwrap.TextWrapper(subsequent_indent='')
+    print(wrapper.fill("If no solver manager is specified, Coopr uses the serial solver manager to execute solvers locally.  The pyro and phpyro solver managers require the installation and configuration of the pyro software.  The neos solver manager is used to execute solvers on the NEOS optimization server."))
+    print("")
+    print(wrapper.fill("The serial, pyro and phpyro solver managers support the following solver interfaces:"))
     print("")
     solver_list = coopr.opt.SolverFactory.services()
     solver_list = sorted( filter(lambda x: '_' != x[0], solver_list) )
@@ -46,23 +66,27 @@ def print_solvers():
         print(wrapper.fill(format % (s , coopr.opt.SolverFactory.doc(s))))
     print("")
     wrapper = textwrap.TextWrapper(subsequent_indent='')
-    print(wrapper.fill("An asterisk indicates that this solver is currently available to be run from Coopr."))
+    print(wrapper.fill("An asterisk indicates that this solver is currently available to be run from Coopr with the serial solver manager."))
     print("")
-    print(wrapper.fill('Several solver interfaces are wrappers around third-party solver interfaces:  openopt and os.  These interfaces require a subsolver specification that indicates the solver being executed.  For example, the following indicates that the OpenOpt pswarm solver is being used:'))
+    print(wrapper.fill('Several solver interfaces are wrappers around third-party solver interfaces:  asl, openopt and os.  These interfaces require a subsolver specification that indicates the solver being executed.  For example, the following indicates that the OpenOpt pswarm solver is being used:'))
     print('')
     print('   openopt:pswarm')
     print('')
-    print(wrapper.fill('The OpenOpt optimization package will launch the pswarm solver to perform optimization.  Currently, subsolvers can not be enumerated automatically for users.'))
+    print(wrapper.fill('The OpenOpt optimization package will launch the pswarm solver to perform optimization.  Similarly, the following indicates that the ipopt solver will be used:'))
+    print('')
+    print('   asl:ipopt')
+    print('')
+    print(wrapper.fill('The asl interface provides a generic wrapper for all solvers that use the AMPL Solver Library.'))
+    print('')
+    print(wrapper.fill('Note that subsolvers can not be enumerated automatically for these interfaces.  However, if a solver is specified that is not found, Coopr assumes that the asl solver interface is being used.  Thus the following solver name will launch ipopt if the \'ipopt\' executable is on the user\'s path:'))
+    print('')
+    print('   ipopt')
+    print('')
 
 
 def main_exec(options):
-    import coopr.pyomo.check as check
-    if options.options:
-        print("TODO - print solver options")
-    elif options.summary:
-        print_solvers()
-    else:
-        print("No solver action specified.")
+    print_solvers()
+
 
 def test_exec(options):
     try:
@@ -84,9 +108,8 @@ def test_exec(options):
 setup_solvers_parser(
     coopr.misc.coopr_parser.add_subparser('solvers',
         func=main_exec, 
-        help='Print information on Coopr solvers.',
-        description='This coopr subcommand is used to print solver information.',
-        epilog='Note that the different options are meant to be used exclusively.  Additionally, the solver name is not used when listing all solvers.'
+        help='Print information about Coopr solvers.',
+        description='This coopr subcommand is used to print solver information.'
         ))
 
 setup_test_parser(
