@@ -16,6 +16,7 @@ import xml
 import coopr.opt
 import coopr.opt.blackbox
 from coopr.opt import ResultsFormat, ProblemFormat
+from coopr.plugins.solvers import ps
 import pyutilib.th as unittest
 import pyutilib.component.core
 import pyutilib.services
@@ -121,7 +122,7 @@ class Test(unittest.TestCase):
 
     def do_setup(self,flag):
         pyutilib.services.TempfileManager.tempdir = currdir
-        self.ps = coopr.plugins.solvers.ps.PatternSearch()
+        self.ps = ps.PatternSearch()
 
     def tearDown(self):
         pyutilib.services.TempfileManager.clear_tempfiles()
